AttriaxApiClient class
Constructors
-
AttriaxApiClient({Dio? dio, Serializers? serializers, String? basePathOverride, List<
Interceptor> ? interceptors})
Properties
- dio → Dio
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serializers → Serializers
-
final
Methods
-
getSdkApi(
) → SdkApi - Get SdkApi instance, base route and serializer can be overridden by a given but be careful, by doing that all interceptors will not be executed
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeApiKey(
String name) → void -
Removes the API key associated with the given
name. -
removeBasicAuth(
String name) → void -
Removes the basic authentication credentials associated with the given
name. -
removeBearerAuth(
String name) → void -
Removes the bearer authentication token associated with the given
name. -
removeOAuthToken(
String name) → void -
Removes the OAuth token associated with the given
name. -
setApiKey(
String name, String apiKey) → void -
setBasicAuth(
String name, String username, String password) → void -
setBearerAuth(
String name, String token) → void -
setOAuthToken(
String name, String token) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited