SdkRegisterUninstallTokenDto class abstract

SdkRegisterUninstallTokenDto

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SdkRegisterUninstallTokenDto([void updates(SdkRegisterUninstallTokenDtoBuilder b)])
factory

Properties

appToken String
no setter
deviceId String
no setter
deviceIdSource String?
no setter
hashCode int
The hash code for this object.
no setterinherited
metadata → BuiltMap<String, JsonObject?>?
no setter
platform Platform
no setter
provider AppUserUninstallTokenProvider
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token → JsonObject?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SdkRegisterUninstallTokenDtoBuilder)) SdkRegisterUninstallTokenDto
Rebuilds the instance.
inherited
toBuilder() SdkRegisterUninstallTokenDtoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SdkRegisterUninstallTokenDto>
no setter