SdkRegisterUninstallTokenDtoBuilder class

Properties

appToken String?
getter/setter pair
deviceId String?
getter/setter pair
deviceIdSource String?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
metadata ↔ MapBuilder<String, JsonObject?>
getter/setter pair
platform Platform?
getter/setter pair
provider AppUserUninstallTokenProvider?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token ↔ JsonObject?
getter/setter pair

Methods

build() SdkRegisterUninstallTokenDto
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(SdkRegisterUninstallTokenDto other) → void
Replaces the value in the builder with a new one.
override
toString() String
A string representation of this object.
inherited
update(void updates(SdkRegisterUninstallTokenDtoBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited