SdkV1DeepLinkResolveDto class abstract

Annotations
  • @BuiltValue.new()

Constructors

SdkV1DeepLinkResolveDto([void updates(SdkV1DeepLinkResolveDtoBuilder b)])
factory

Properties

appToken String
no setter
deviceId String
no setter
deviceIdSource String?
no setter
hashCode int
The hash code for this object.
no setterinherited
isFirstLaunch bool?
no setter
linkPath String?
no setter
metadata → BuiltMap<String, JsonObject?>?
no setter
platform Platform
no setter
rawUrl String?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source_ String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SdkV1DeepLinkResolveDtoBuilder)) SdkV1DeepLinkResolveDto
Rebuilds the instance.
inherited
toBuilder() SdkV1DeepLinkResolveDtoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SdkV1DeepLinkResolveDto>
no setter