SdkVersionContextDto class abstract

SdkVersionContextDto

Properties:

Annotations
  • @BuiltValue.new()

Constructors

SdkVersionContextDto([void updates(SdkVersionContextDtoBuilder b)])
factory

Properties

apiVersion String
no setter
hashCode int
The hash code for this object.
no setterinherited
metadata → BuiltMap<String, JsonObject?>?
no setter
packageVersion String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(SdkVersionContextDtoBuilder)) SdkVersionContextDto
Rebuilds the instance.
inherited
toBuilder() SdkVersionContextDtoBuilder
Converts the instance to a builder B.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

serializer → Serializer<SdkVersionContextDto>
no setter