SdkCrashDto class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
SdkCrashDto({String? appBuildNumber, String? appPackageName, String? appToken, String? appVersion, required DateTime clientOccurredAt, String? deviceId, String? deviceIdSource, required String exceptionType, required bool isFatal, required bool isFirstLaunch, String? locale, required String message, Map<
String, Object> ? metadata, required Platform platform, String? projectToken, String? reason, String? sdkApiVersion, String? sdkPackageVersion, String? sessionId, num? sessionRelativeTimeMs, required String source_, required String stackTrace}) - Returns a new SdkCrashDto instance.
-
SdkCrashDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- appBuildNumber → String?
-
final
- appPackageName → String?
-
final
- appToken → String?
-
Deprecated alias for projectToken kept for released SDK compatibility.
final
- appVersion → String?
-
final
- clientOccurredAt → DateTime
-
final
- deviceId → String?
-
final
- deviceIdSource → String?
-
final
- exceptionType → String
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFatal → bool
-
final
- isFirstLaunch → bool
-
final
- locale → String?
-
final
- message → String
-
final
-
metadata
→ Map<
String, Object> ? -
final
- platform → Platform
-
final
- projectToken → String?
-
Attriax project token that scopes the SDK request.
final
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdkApiVersion → String?
-
final
- sdkPackageVersion → String?
-
final
- sessionId → String?
-
final
- sessionRelativeTimeMs → num?
-
Milliseconds since the session started. Fractional values are allowed.
final
- source_ → String
-
Crash origin inside the SDK or native bridge.
final
- stackTrace → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override