SdkDynamicLinkRecordDto class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
-
SdkDynamicLinkRecordDto({bool? androidRedirect, required DateTime createdAt, Map<
String, Object> ? data, String? destinationUrl, String? group, required String id, bool? iosRedirect, String? name, required String path, String? prefix, String? previewDescription, String? previewTitle, required String shortUrl, String? utmCampaign, String? utmContent, String? utmMedium, String? utmSource, String? utmTerm}) - Returns a new SdkDynamicLinkRecordDto instance.
-
SdkDynamicLinkRecordDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- androidRedirect → bool?
-
final
- createdAt → DateTime
-
final
-
data
→ Map<
String, Object> ? -
final
- destinationUrl → String?
-
final
- group → String?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- id → String
-
final
- iosRedirect → bool?
-
final
- name → String?
-
final
- path → String
-
final
- prefix → String?
-
final
- previewDescription → String?
-
final
- previewTitle → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shortUrl → String
-
final
- utmCampaign → String?
-
final
- utmContent → String?
-
final
- utmMedium → String?
-
final
- utmSource → String?
-
final
- utmTerm → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override