SdkEventDto class abstract
SdkEventDto
Properties:
- appToken
- clientOccurredAt
- deviceId
- deviceIdSource
- eventData
- eventName
- sessionId
- sessionRelativeTimeMs - Milliseconds since the session started.
- Annotations
-
- @BuiltValue.new()
Constructors
- SdkEventDto([void updates(SdkEventDtoBuilder b)])
-
factory
Properties
- appToken → String
-
no setter
- clientOccurredAt → DateTime?
-
no setter
- deviceId → String
-
no setter
- deviceIdSource → String?
-
no setter
-
eventData
→ BuiltMap<
String, JsonObject?> ? -
no setter
- eventName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
no setter
- sessionRelativeTimeMs → num?
-
Milliseconds since the session started.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
rebuild(
dynamic updates(SdkEventDtoBuilder)) → SdkEventDto -
Rebuilds the instance.
inherited
-
toBuilder(
) → SdkEventDtoBuilder -
Converts the instance to a builder
B.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
serializer
→ Serializer<
SdkEventDto> -
no setter