SdkV1DeepLinkResolveResponseDto class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
- SdkV1DeepLinkResolveResponseDto({required DateTime acceptedAt, SdkBrowserActionDto? browserAction, required DateTime consumedAt, SdkJsonDeepLinkDto? deepLink, required bool isFirstLaunch, required bool matched, String? reason, required String requestVersion, required DeepLinkResolutionStatus status})
- Returns a new SdkV1DeepLinkResolveResponseDto instance.
-
SdkV1DeepLinkResolveResponseDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- acceptedAt → DateTime
-
final
- browserAction → SdkBrowserActionDto?
-
final
- consumedAt → DateTime
-
final
- deepLink → SdkJsonDeepLinkDto?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- isFirstLaunch → bool
-
final
- matched → bool
-
final
- reason → String?
-
final
- requestVersion → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → DeepLinkResolutionStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override