SdkV1OpenDto class
- Annotations
-
- @JsonSerializable.new(checked: true, createToJson: true, disallowUnrecognizedKeys: false, explicitToJson: true)
Constructors
- SdkV1OpenDto({required AppVersionContextDto app, String? appToken, required DeviceContextDto device, required String deviceId, String? deviceIdSource, bool? googlePlayInstantParam, num? installBeginTimestampSeconds, String? installReferrer, bool? isFirstLaunch, required Platform platform, String? projectToken, num? referrerClickTimestampSeconds, required SdkVersionContextDto sdk, String? sessionId, DateTime? sessionStartedAt})
- Returns a new SdkV1OpenDto instance.
-
SdkV1OpenDto.fromJson(Map<
String, dynamic> json) -
factory
Properties
- app → AppVersionContextDto
-
final
- appToken → String?
-
Deprecated alias for projectToken kept for released SDK compatibility.
final
- device → DeviceContextDto
-
final
- deviceId → String
-
final
- deviceIdSource → String?
-
final
- googlePlayInstantParam → bool?
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- installBeginTimestampSeconds → num?
-
final
- installReferrer → String?
-
final
- isFirstLaunch → bool?
-
final
- platform → Platform
-
final
- projectToken → String?
-
Attriax project token that scopes the SDK request.
final
- referrerClickTimestampSeconds → num?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sdk → SdkVersionContextDto
-
final
- sessionId → String?
-
final
- sessionStartedAt → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override